// src/list-markdown.ts
var listMarkdownPlugin = (md, _options) => {
  md.core.ruler.after("inline", "bangle-list-kind-attrs", (state) => {
    const tokens = state.tokens;
    let currentListKind = null;
    for (let i = 0; i < tokens.length; i++) {
      const token = tokens[i];
      if (isBulletListOpen(token)) {
        currentListKind = "bullet";
        token?.attrSet("data-bangle-list-kind", "bullet");
      } else if (isOrderedListOpen(token)) {
        currentListKind = "ordered";
        token?.attrSet("data-bangle-list-kind", "ordered");
      } else if (token?.type === "bullet_list_close" || token?.type === "ordered_list_close") {
        currentListKind = null;
      } else if (token?.type === "list_item_open" && currentListKind) {
        if (!token.attrGet("data-bangle-list-kind")) {
          token.attrSet("data-bangle-list-kind", currentListKind);
        }
      }
    }
    return false;
  });
  md.core.ruler.after("inline", "bangle-task-lists", (state) => {
    const tokens = state.tokens;
    for (let i = 2; i < tokens.length; i++) {
      if (isTodoItem(tokens, i)) {
        convertToTaskItem(tokens, i);
      }
    }
    return false;
  });
  const originalRenderToken = md.renderer.renderToken.bind(md.renderer);
  md.renderer.renderToken = (tokens, idx, options) => {
    const token = tokens[idx];
    if (token?.type === "list_item_open") {
      const kindAttr = token?.attrGet("data-bangle-list-kind");
      if (kindAttr === "task") {
        const checkedAttr = token.attrGet("data-bangle-task-checked") || "false";
        token.attrSet("data-bangle-task-checked", checkedAttr);
      }
    }
    return originalRenderToken(tokens, idx, options);
  };
};
function isOrderedListOpen(token) {
  return token?.type === "ordered_list_open";
}
function isBulletListOpen(token) {
  return token?.type === "bullet_list_open";
}
function isTodoItem(tokens, index) {
  return isInline(tokens[index]) && isParagraphOpen(tokens[index - 1]) && isListItemOpen(tokens[index - 2]) && startsWithTodoMarkdown(tokens[index]?.content);
}
function startsWithTodoMarkdown(content) {
  if (!content) return false;
  const prefix = content.slice(0, 4).toLowerCase();
  return prefix === "[ ] " || prefix === "[x] ";
}
function convertToTaskItem(tokens, index) {
  const listItemOpen = tokens[index - 2];
  const inlineToken = tokens[index];
  if (!listItemOpen || !inlineToken || !inlineToken.children) return;
  listItemOpen.attrSet("data-bangle-list-kind", "task");
  const firstChild = inlineToken.children[0];
  if (firstChild?.type === "text") {
    const text = firstChild.content;
    const isChecked = text[1]?.toLowerCase() === "x";
    listItemOpen.attrSet(
      "data-bangle-task-checked",
      isChecked ? "true" : "false"
    );
    if (text.startsWith("[ ] ") || text.startsWith("[x] ") || text.startsWith("[X] ")) {
      firstChild.content = text.slice(4);
    }
  }
}
function isInline(token) {
  return token?.type === "inline";
}
function isParagraphOpen(token) {
  return token?.type === "paragraph_open";
}
function isListItemOpen(token) {
  return token?.type === "list_item_open";
}

export {
  listMarkdownPlugin
};
