import { PluginWithOptions } from 'markdown-it';

/**
 * This plugin is responsible for customizing how bullet, ordered,
 * and task lists are parsed and rendered in Markdown. Since
 * markdown-it does NOT set task attributes by default,
 * we detect tasks ourselves by checking for "[ ] ", "[x] ", or "[X] "
 * at the beginning of a list item after inline processing. We then
 * mark those list items with data-bangle-list-kind="task"
 * and set data-bangle-task-checked="true"/"false".
 *
 * We ignore label logic or other UI aspects, leaving that to ProseMirror.
 */
type ListMarkdownPluginOptions = Record<string, never>;
declare const listMarkdownPlugin: PluginWithOptions<ListMarkdownPluginOptions>;

export { type ListMarkdownPluginOptions, listMarkdownPlugin };
